package net.sourceforge.jenesis4java;

import java.util.List;

/**
 * Copyright (C) 2008, 2010 Richard van Nieuwenhoven - ritchie [at] gmx [dot] at
 * Copyright (C) 2000, 2001 Paul Cody Johnston - pcj@inxar.org <br>
 * This file is part of Jenesis4java. Jenesis4java is free software: you can
 * redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.<br>
 * Jenesis4java is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.<br>
 * You should have received a copy of the GNU Lesser General Public License
 * along with Jenesis4java. If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * <code>Expression</code> subinterface for expressions which create new
 * non-array objects.
 */
public interface NewClass extends Expression {

    /**
     * Adds the given expression the list of arguments for this new invocation.
     */
    NewClass addArg(Expression e);

    /**
     * Gets the list of arguments for this instance creation as an list of
     * <code>Expression</code>.
     */
    List<Expression> getArgs();

    /**
     * Sets the qualifier for this instance creation.
     */
    String getQualifier();

    /**
     * Sets the qualifier for this instance creation. This is a feature needed
     * only when expressing instance creation of a non-static inner class.
     * Typically it will remain null.
     */
    NewClass setQualifier(String s);

    /**
     * Sets the given type for this instance creation.
     */
    NewClass setType(Type type);
}
